@@ -53,6 +53,7 @@ NADataDef data_def_conditions [] = {
 					"Defaults to '*'." ),
 				NAFD_TYPE_STRING_LIST,
 				"[*]",
+				FALSE,
 				TRUE,
 				TRUE,
 				FALSE,
@@ -81,6 +82,7 @@ NADataDef data_def_conditions [] = {
 					"Defaults to 'true'." ),
 				NAFD_TYPE_BOOLEAN,
 				"true",
+				FALSE,
 				TRUE,
 				TRUE,
 				FALSE,
@@ -103,9 +105,10 @@ NADataDef data_def_conditions [] = {
 					"selected file(s)/folder(s). Each selected items must match at least one of " \
 					"the mimetype patterns for the action to appear.\n" \
 					"This obviously only applies when there is a selection.\n" \
-					"Defaults to '*'." ),
+					"Defaults to '*/*'." ),
 				NAFD_TYPE_STRING_LIST,
-				"[*]",
+				"[*/*]",
+				FALSE,
 				TRUE,
 				TRUE,
 				FALSE,
@@ -121,6 +124,35 @@ NADataDef data_def_conditions [] = {
 					"You must set one option for each pattern you need" ),
 				N_( "<EXPR>" ) },
 
+	/* a runtime boolean set to TRUE if we detect that the previous string list
+	 * just cover all mimetypes - this let us optimize the check for candidate
+	 * in the menu plugin
+	 * when FALSE, than we have to check each and every mimetype :(
+	 */
+	{ NAFO_DATA_ALL_MIMETYPES,
+				FALSE,
+				FALSE,
+				TRUE,
+				"Does the mimetypes list is generic ?",
+				"The generic wildcard may be coded as '*', or '*/*' or 'all' or 'all/*' or 'all/all'."
+				"In each case, we will try to spend as less time as possible to check " \
+				"selection mimetypes",
+				NAFD_TYPE_BOOLEAN,
+				"true",
+				FALSE,
+				TRUE,
+				TRUE,
+				FALSE,
+				FALSE,
+				NULL,
+				NULL,
+				0,
+				NULL,
+				0,
+				0,
+				NULL,
+				NULL },
+
 	{ NAFO_DATA_ISFILE,
 				TRUE,
 				TRUE,
@@ -137,6 +169,7 @@ NADataDef data_def_conditions [] = {
 					"Defaults to 'true'." ),
 				NAFD_TYPE_BOOLEAN,
 				"true",
+				FALSE,
 				TRUE,
 				TRUE,
 				FALSE,
@@ -166,6 +199,7 @@ NADataDef data_def_conditions [] = {
 					"Defaults to 'false'." ),
 				NAFD_TYPE_BOOLEAN,
 				"false",
+				FALSE,
 				TRUE,
 				TRUE,
 				FALSE,
@@ -179,10 +213,13 @@ NADataDef data_def_conditions [] = {
 				NULL,
 				NULL },
 
+	/* this is obsoleted starting with 2.30-newdata (released as 2.31.x serie)
+	 * and replaced by selection-count
+	 */
 	{ NAFO_DATA_MULTIPLE,
 				TRUE,
-				TRUE,
-				TRUE,
+				FALSE,
+				FALSE,
 				N_( "Whether the selection may be multiple" ),
 				N_( "If you need more than one files or folders to be selected, set this " \
 					"key to 'true'. If you want just one file or folder, set it to 'false'.\n" \
@@ -190,14 +227,15 @@ NADataDef data_def_conditions [] = {
 					"Defaults to 'false'." ),
 				NAFD_TYPE_BOOLEAN,
 				"false",
-				TRUE,
-				TRUE,
+				FALSE,
+				FALSE,
+				FALSE,
 				FALSE,
 				FALSE,
 				"accept-multiple-files",
 				NULL,
-				'u',
-				"accept-multiple",
+				0,
+				NULL,
 				0,
 				G_OPTION_ARG_NONE,
 				NULL,
@@ -226,7 +264,8 @@ NADataDef data_def_conditions [] = {
 					"or when targeting the special 'x-nautilus-desktop' scheme.\n" \
 					"Defaults to 'file'." ),
 				NAFD_TYPE_STRING_LIST,
-				"[file]",
+				"[*]",
+				FALSE,
 				TRUE,
 				TRUE,
 				FALSE,
@@ -251,6 +290,7 @@ NADataDef data_def_conditions [] = {
 					"Defaults to '/'." ),
 				NAFD_TYPE_STRING_LIST,
 				"[/]",
+				FALSE,
 				TRUE,
 				TRUE,
 				FALSE,
@@ -265,5 +305,204 @@ NADataDef data_def_conditions [] = {
 					"You must set one option for each folder you need" ),
 				N_( "<PATH>" ) },
 
+	{ NAFO_DATA_SELECTION_COUNT,
+				TRUE,
+				TRUE,
+				TRUE,
+				N_( "Operator of the selection count relation" ),
+				N_( "Whether this profile may be selected depending of the count of the selection.\n" \
+					"This is a string of the form \"{'<'|'='|'>'} number\".\n" \
+					"Examples of valid strings are: \"=0\", \"> 1\", \"< 10\".\n" \
+					"Defaults to \">0\"." ),
+				NAFD_TYPE_STRING,
+				">0",
+				FALSE,
+				TRUE,
+				TRUE,
+				FALSE,
+				FALSE,
+				"selection-count",
+				"SelectionCount",
+				0,
+				NULL,
+				0,
+				G_OPTION_ARG_NONE,
+				NULL,
+				NULL },
+
+	{ NAFO_DATA_ONLY_SHOW,
+				TRUE,
+				TRUE,
+				TRUE,
+				N_( "Only show in environment" ),
+				N_( "Defaults to all." ),
+				NAFD_TYPE_STRING_LIST,
+				NULL,
+				FALSE,
+				TRUE,
+				TRUE,
+				FALSE,
+				FALSE,
+				"only-show-in",
+				"OnlyShowIn",
+				0,
+				NULL,
+				0,
+				G_OPTION_ARG_NONE,
+				NULL,
+				NULL },
+
+	{ NAFO_DATA_NOT_SHOW,
+				TRUE,
+				TRUE,
+				TRUE,
+				N_( "Not show in environment" ),
+				N_( "Defaults to none." ),
+				NAFD_TYPE_STRING_LIST,
+				NULL,
+				FALSE,
+				TRUE,
+				TRUE,
+				FALSE,
+				FALSE,
+				"not-show-in",
+				"NotShowIn",
+				0,
+				NULL,
+				0,
+				G_OPTION_ARG_NONE,
+				NULL,
+				NULL },
+
+	{ NAFO_DATA_TRY_EXEC,
+				TRUE,
+				TRUE,
+				TRUE,
+				N_( "Try exec" ),
+				N_( "Note that, when specified, only the presence and the executability status of " \
+					"the specified file are checked.\n" \
+					"Parameters may appear in TryExec value, and will be substituted at runtime.\n" \
+					"Defaults to successful." ),
+				NAFD_TYPE_STRING,
+				NULL,
+				FALSE,
+				TRUE,
+				TRUE,
+				FALSE,
+				FALSE,
+				"try-exec",
+				"TryExec",
+				0,
+				NULL,
+				0,
+				G_OPTION_ARG_NONE,
+				NULL,
+				NULL },
+
+	{ NAFO_DATA_SHOW_IF_REGISTERED,
+				TRUE,
+				TRUE,
+				TRUE,
+				N_( "Show if registered" ),
+				N_( "The well-known name of a DBus service.\n" \
+					"The item will be candidate if the named service is registered on session DBus at runtime.\n" \
+					"Parameters may appear in ShowIfRegistered value, and will be substituted at runtime.\n" \
+					"Defaults to successful." ),
+				NAFD_TYPE_STRING,
+				NULL,
+				FALSE,
+				TRUE,
+				TRUE,
+				FALSE,
+				FALSE,
+				"show-if-registered",
+				"ShowIfRegistered",
+				0,
+				NULL,
+				0,
+				G_OPTION_ARG_NONE,
+				NULL,
+				NULL },
+
+	{ NAFO_DATA_SHOW_IF_TRUE,
+				TRUE,
+				TRUE,
+				TRUE,
+				N_( "Show if True" ),
+				N_( "A command which, when executed, should output a string on stdout.\n" \
+					"The item will be candidate if the outputed string is equal to \"true\".\n" \
+					"Parameters may appear in ShowIfTrue value, and will be substituted at runtime.\n" \
+					"Defaults to successful." ),
+				NAFD_TYPE_STRING,
+				NULL,
+				FALSE,
+				TRUE,
+				TRUE,
+				FALSE,
+				FALSE,
+				"show-if-true",
+				"ShowIfTrue",
+				0,
+				NULL,
+				0,
+				G_OPTION_ARG_NONE,
+				NULL,
+				NULL },
+
+	{ NAFO_DATA_SHOW_IF_RUNNING,
+				TRUE,
+				TRUE,
+				TRUE,
+				N_( "Show if running" ),
+				N_( "The name of a process.\n" \
+					"The item will be candidate if the process name is found in memory at runtime.\n" \
+					"Parameters may appear in ShowIfRunning value, and will be substituted at runtime.\n" \
+					"Defaults to successful." ),
+				NAFD_TYPE_STRING,
+				NULL,
+				FALSE,
+				TRUE,
+				TRUE,
+				FALSE,
+				FALSE,
+				"show-if-running",
+				"ShowIfRunning",
+				0,
+				NULL,
+				0,
+				G_OPTION_ARG_NONE,
+				NULL,
+				NULL },
+
+	{ NAFO_DATA_CAPABILITITES,
+				TRUE,
+				TRUE,
+				TRUE,
+				N_( "Capabilities" ),
+				N_( "A list of capabilities each item of the selection must satisfy in order the item be candidate.\n" \
+					"Capabilities may be negated.\n" \
+					"Capabilities have to be choosen between following predefined ones:\n" \
+					"- Owner: current user is the owner of selected items\n" \
+					"- Readable: selected items are readable by user (probably more usefull when negated)\n" \
+					"- Writable: selected items are writable by user\n" \
+					"- Executable: selected items are executable by user\n" \
+					"- Local: selected items are local.\n" \
+					"Defaults to empty list." ),
+				NAFD_TYPE_STRING_LIST,
+				NULL,
+				FALSE,
+				TRUE,
+				TRUE,
+				FALSE,
+				FALSE,
+				"capabilities",
+				"Capabilities",
+				0,
+				NULL,
+				0,
+				G_OPTION_ARG_NONE,
+				NULL,
+				NULL },
+
 	{ NULL },
 };
