@@ -52,7 +52,7 @@ struct NadpDesktopFileClassPrivate {
 struct NadpDesktopFilePrivate {
 	gboolean   dispose_has_run;
 	gchar     *id;
-	gchar     *path;
+	gchar     *uri;
 	GKeyFile  *key_file;
 };
 
@@ -64,8 +64,9 @@ static void             instance_init( GTypeInstance *instance, gpointer klass )
 static void             instance_dispose( GObject *object );
 static void             instance_finalize( GObject *object );
 
-static NadpDesktopFile *ndf_new( const gchar *path );
+static NadpDesktopFile *ndf_new( const gchar *uri );
 static gchar           *path2id( const gchar *path );
+static gchar           *uri2id( const gchar *uri );
 static gboolean         check_key_file( NadpDesktopFile *ndf );
 
 GType
@@ -169,7 +170,7 @@ instance_finalize( GObject *object )
 	self = NADP_DESKTOP_FILE( object );
 
 	g_free( self->private->id );
-	g_free( self->private->path );
+	g_free( self->private->uri );
 
 	if( self->private->key_file ){
 		g_key_file_free( self->private->key_file );
@@ -183,6 +184,21 @@ instance_finalize( GObject *object )
 	}
 }
 
+/**
+ * nadp_desktop_file_new:
+ *
+ * Retuns: a newly allocated #NadpDesktopFile object.
+ */
+NadpDesktopFile *
+nadp_desktop_file_new( void )
+{
+	NadpDesktopFile *ndf;
+
+	ndf = g_object_new( NADP_DESKTOP_FILE_TYPE, NULL );
+
+	return( ndf );
+}
+
 /**
  * nadp_desktop_file_new_from_path:
  * @path: the full pathname of a .desktop file.
@@ -197,14 +213,25 @@ nadp_desktop_file_new_from_path( const gchar *path )
 	static const gchar *thisfn = "nadp_desktop_file_new_from_path";
 	NadpDesktopFile *ndf;
 	GError *error;
+	gchar *uri;
 
 	ndf = NULL;
 	g_debug( "%s: path=%s", thisfn, path );
 	g_return_val_if_fail( path && g_utf8_strlen( path, -1 ) && g_path_is_absolute( path ), ndf );
 
-	ndf = ndf_new( path );
-
 	error = NULL;
+	uri = g_filename_to_uri( path, NULL, &error );
+	if( !uri || error ){
+		g_warning( "%s: %s: %s", thisfn, path, error->message );
+		g_error_free( error );
+		g_free( uri );
+		return( NULL );
+	}
+
+	ndf = ndf_new( uri );
+
+	g_free( uri );
+
 	g_key_file_load_from_file( ndf->private->key_file, path, G_KEY_FILE_KEEP_COMMENTS | G_KEY_FILE_KEEP_TRANSLATIONS, &error );
 	if( error ){
 		g_warning( "%s: %s: %s", thisfn, path, error->message );
@@ -221,6 +248,56 @@ nadp_desktop_file_new_from_path( const gchar *path )
 	return( ndf );
 }
 
+/**
+ * nadp_desktop_file_new_from_uri:
+ * @uri: the URI the desktop file should be loaded from.
+ *
+ * Retuns: a newly allocated #NadpDesktopFile object, or %NULL.
+ *
+ * Key file has been loaded, and first validity checks made.
+ *
+ * Note: This function is in particular used when importing a file.
+ * So it is rather common that the file not be a .desktop one.
+ * Do not warns when file is malformed.
+ */
+NadpDesktopFile *
+nadp_desktop_file_new_from_uri( const gchar *uri )
+{
+	static const gchar *thisfn = "nadp_desktop_file_new_from_uri";
+	NadpDesktopFile *ndf;
+	GError *error;
+	gchar *data;
+	gsize length;
+
+	ndf = NULL;
+	g_debug( "%s: uri=%s", thisfn, uri );
+	g_return_val_if_fail( uri && g_utf8_strlen( uri, -1 ), ndf );
+
+	ndf = ndf_new( uri );
+	data = na_core_utils_file_load_from_uri( uri, &length );
+
+	error = NULL;
+	g_key_file_load_from_data( ndf->private->key_file, data, length, G_KEY_FILE_KEEP_COMMENTS | G_KEY_FILE_KEEP_TRANSLATIONS, &error );
+	if( error ){
+		if( error->code != G_KEY_FILE_ERROR_GROUP_NOT_FOUND ){
+			g_warning( "%s: %s", thisfn, error->message );
+		}
+		g_error_free( error );
+		g_object_unref( ndf );
+		g_free( data );
+		return( NULL );
+	}
+
+	g_free( data );
+
+	if( !check_key_file( ndf )){
+		g_object_unref( ndf );
+		return( NULL );
+	}
+
+	return( ndf );
+}
+
 /**
  * nadp_desktop_file_new_for_write:
  * @path: the full pathname of a .desktop file.
@@ -232,66 +309,90 @@ nadp_desktop_file_new_for_write( const gchar *path )
 {
 	static const gchar *thisfn = "nadp_desktop_file_new_for_write";
 	NadpDesktopFile *ndf;
+	GError *error;
+	gchar *uri;
 
 	ndf = NULL;
 	g_debug( "%s: path=%s", thisfn, path );
 	g_return_val_if_fail( path && g_utf8_strlen( path, -1 ) && g_path_is_absolute( path ), ndf );
 
-	ndf = ndf_new( path );
+	error = NULL;
+	uri = g_filename_to_uri( path, NULL, &error );
+	if( !uri || error ){
+		g_warning( "%s: %s: %s", thisfn, path, error->message );
+		g_error_free( error );
+		g_free( uri );
+		return( NULL );
+	}
+
+	ndf = ndf_new( uri );
+
+	g_free( uri );
 
 	return( ndf );
 }
 
 /**
- * nadp_desktop_file_get_key_file_path:
+ * nadp_desktop_file_get_key_file:
  * @ndf: the #NadpDesktopFile instance.
  *
- * Returns: the full pathname of the key file, as a newly allocated
- * string which should be g_free() by the caller.
+ * Returns: a pointer to the internal #GKeyFile.
  */
-gchar *
-nadp_desktop_file_get_key_file_path( const NadpDesktopFile *ndf )
+GKeyFile *
+nadp_desktop_file_get_key_file( const NadpDesktopFile *ndf )
 {
-	gchar *path;
+	GKeyFile *key_file;
 
 	g_return_val_if_fail( NADP_IS_DESKTOP_FILE( ndf ), NULL );
 
-	path = NULL;
+	key_file = NULL;
 
 	if( !ndf->private->dispose_has_run ){
 
-		path = g_strdup( ndf->private->path );
+		key_file = ndf->private->key_file;
 	}
 
-	return( path );
+	return( key_file );
 }
 
-/*
- * ndf_new:
- * @path: the full pathname of a .desktop file.
+/**
+ * nadp_desktop_file_get_key_file_uri:
+ * @ndf: the #NadpDesktopFile instance.
  *
- * Retuns: a newly allocated #NadpDesktopFile object.
+ * Returns: the URI of the key file, as a newly allocated
+ * string which should be g_free() by the caller.
  */
+gchar *
+nadp_desktop_file_get_key_file_uri( const NadpDesktopFile *ndf )
+{
+	gchar *uri;
+
+	g_return_val_if_fail( NADP_IS_DESKTOP_FILE( ndf ), NULL );
+
+	uri = NULL;
+
+	if( !ndf->private->dispose_has_run ){
+
+		uri = g_strdup( ndf->private->uri );
+	}
+
+	return( uri );
+}
+
 static NadpDesktopFile *
-ndf_new( const gchar *path )
+ndf_new( const gchar *uri )
 {
 	NadpDesktopFile *ndf;
 
 	ndf = g_object_new( NADP_DESKTOP_FILE_TYPE, NULL );
 
-	ndf->private->id = path2id( path );
-	ndf->private->path = g_strdup( path );
+	ndf->private->id = uri2id( uri );
+	ndf->private->uri = g_strdup( uri );
 
 	return( ndf );
 }
 
 /*
- * path2id:
- * @path: a full pathname.
- *
- * Returns: the id of the file, as a newly allocated string which
- * should be g_free() by the caller.
- *
  * The id of the file is equal to the basename, minus the suffix.
  */
 static gchar *
@@ -307,24 +408,64 @@ path2id( const gchar *path )
 	return( id );
 }
 
+static gchar *
+uri2id( const gchar *uri )
+{
+	gchar *path;
+	gchar *id;
+
+	id = NULL;
+	path = g_filename_from_uri( uri, NULL, NULL );
+
+	if( path ){
+		id = path2id( path );
+		g_free( path );
+	}
+
+	return( id );
+}
+
 static gboolean
 check_key_file( NadpDesktopFile *ndf )
 {
 	static const gchar *thisfn = "nadp_desktop_file_check_key_file";
 	gboolean ret;
 	gchar *start_group;
+	gboolean has_key;
+	gboolean hidden;
+	GError *error;
 
 	ret = TRUE;
+	error = NULL;
 
-	/* start group must be 'Desktop Entry' */
+	/* start group must be [Desktop Entry] */
 	start_group = g_key_file_get_start_group( ndf->private->key_file );
 	if( strcmp( start_group, NADP_GROUP_DESKTOP )){
-
 		g_warning( "%s: %s: invalid start group, found %s, waited for %s",
-				thisfn, ndf->private->path, start_group, NADP_GROUP_DESKTOP );
+				thisfn, ndf->private->uri, start_group, NADP_GROUP_DESKTOP );
 		ret = FALSE;
 	}
 
+	/* must not have Hidden=true value */
+	if( ret ){
+		has_key = g_key_file_has_key( ndf->private->key_file, start_group, NADP_KEY_HIDDEN, &error );
+		if( error ){
+			g_warning( "%s: %s: %s", thisfn, ndf->private->uri, error->message );
+			ret = FALSE;
+
+		} else if( has_key ){
+			hidden = g_key_file_get_boolean( ndf->private->key_file, start_group, NADP_KEY_HIDDEN, &error );
+			if( error ){
+				g_warning( "%s: %s: %s", thisfn, ndf->private->uri, error->message );
+				ret = FALSE;
+
+			} else if( hidden ){
+				g_debug( "%s: %s: Hidden=true", thisfn, ndf->private->uri );
+				ret = FALSE;
+			}
+		}
+	}
+
 	g_free( start_group );
 
 	return( ret );
@@ -396,6 +537,116 @@ nadp_desktop_file_get_id( const NadpDesktopFile *ndf )
 	return( value );
 }
 
+/**
+ * nadp_desktop_file_get_profiles:
+ * @ndf: the #NadpDesktopFile instance.
+ *
+ * Returns: the list of profiles in the file, as a newly allocated GSList
+ * which must be na_core_utils_slist_free() by the caller.
+ *
+ * Silently ignore unknown groups.
+ */
+GSList *
+nadp_desktop_file_get_profiles( const NadpDesktopFile *ndf )
+{
+	GSList *list;
+	gchar **groups, **ig;
+	gchar *profile_pfx;
+	gchar *profile_id;
+	guint pfx_len;
+
+	g_return_val_if_fail( NADP_IS_DESKTOP_FILE( ndf ), NULL );
+
+	list = NULL;
+
+	if( !ndf->private->dispose_has_run ){
+
+		groups = g_key_file_get_groups( ndf->private->key_file, NULL );
+		if( groups ){
+			ig = groups;
+			profile_pfx = g_strdup_printf( "%s ", NADP_GROUP_PROFILE );
+			pfx_len = strlen( profile_pfx );
+
+			while( *ig ){
+				if( !strncmp( *ig, profile_pfx, pfx_len )){
+					profile_id = g_strdup( *ig+pfx_len );
+					list = g_slist_prepend( list, profile_id );
+				}
+
+				ig++;
+			}
+
+			g_strfreev( groups );
+			g_free( profile_pfx );
+		}
+	}
+
+	return( list );
+}
+
+/**
+ * nadp_desktop_file_remove_key:
+ * @ndf: this #NadpDesktopFile instance.
+ * @group: the group.
+ * @key: the key.
+ *
+ * Removes the specified key.
+ *
+ * Note that this doesn't work very well for localized keys, as we only
+ * remove a key which has the exact same label that the provided one.
+ * So we'd have to remove:
+ * - key
+ * - key[en_US.UTF-8]
+ * - key[en_US]
+ * - key[en]
+ */
+void
+nadp_desktop_file_remove_key( const NadpDesktopFile *ndf, const gchar *group, const gchar *key )
+{
+	char **locales;
+	char **iloc;
+	gchar *locale_key;
+
+	g_return_if_fail( NADP_IS_DESKTOP_FILE( ndf ));
+
+	if( !ndf->private->dispose_has_run ){
+
+		g_key_file_remove_key( ndf->private->key_file, group, key, NULL );
+
+		locales = ( char ** ) g_get_language_names();
+		iloc = locales;
+
+		while( *iloc ){
+			locale_key = g_strdup_printf( "%s[%s]", key, *iloc );
+			g_key_file_remove_key( ndf->private->key_file, group, locale_key, NULL );
+			g_free( locale_key );
+			iloc++;
+		}
+	}
+}
+
+/**
+ * nadp_desktop_file_remove_profile:
+ * @ndf: this #NadpDesktopFile instance.
+ * @profile_id: the id of the profile.
+ *
+ * Removes the group which describes the specified profile.
+ */
+void
+nadp_desktop_file_remove_profile( const NadpDesktopFile *ndf, const gchar *profile_id )
+{
+	gchar *group_name;
+
+	g_return_if_fail( NADP_IS_DESKTOP_FILE( ndf ));
+
+	if( !ndf->private->dispose_has_run ){
+
+		group_name = g_strdup_printf( "%s %s", NADP_GROUP_PROFILE, profile_id );
+		g_key_file_remove_group( ndf->private->key_file, group_name, NULL );
+		g_free( group_name );
+	}
+}
+
 /**
  * nadp_desktop_file_get_boolean:
  * @ndf: this #NadpDesktopFile instance.
@@ -484,6 +735,7 @@ nadp_desktop_file_get_locale_string( const NadpDesktopFile *ndf, const gchar *gr
 				g_error_free( error );
 				g_free( read_value );
 			}
+
 		} else {
 			g_free( value );
 			value = read_value;
@@ -644,6 +896,130 @@ nadp_desktop_file_get_uint( const NadpDesktopFile *ndf, const gchar *group, cons
 	return( value );
 }
 
+/**
+ * nadp_desktop_file_set_boolean:
+ * @ndf: this #NadpDesktopFile object.
+ * @group: the name of the group.
+ * @key: the name of the key.
+ * @value: the value to be written.
+ *
+ * Write the given boolean value.
+ */
+void
+nadp_desktop_file_set_boolean( const NadpDesktopFile *ndf, const gchar *group, const gchar *key, gboolean value )
+{
+	g_return_if_fail( NADP_IS_DESKTOP_FILE( ndf ));
+
+	if( !ndf->private->dispose_has_run ){
+
+		g_key_file_set_boolean( ndf->private->key_file, group, key, value );
+	}
+}
+
+/**
+ * nadp_desktop_file_set_locale_string:
+ * @ndf: this #NadpDesktopFile object.
+ * @group: the name of the group.
+ * @key: the name of the key.
+ * @value: the value to be written.
+ *
+ * Write the given string value.
+ */
+void
+nadp_desktop_file_set_locale_string( const NadpDesktopFile *ndf, const gchar *group, const gchar *key, const gchar *value )
+{
+	char **locales;
+	guint i;
+
+	g_return_if_fail( NADP_IS_DESKTOP_FILE( ndf ));
+
+	if( !ndf->private->dispose_has_run ){
+
+		locales = ( char ** ) g_get_language_names();
+		/*
+		en_US.UTF-8
+		en_US
+		en.UTF-8
+		en
+		C
+		*/
+
+		/* using locales[0] writes a string with, e.g. Label[en_US.UTF-8]
+		 * after thatn trying to read the same key with another locale, even en_US.utf-8,
+		 * fails ans returns an empty string.
+		 * so write all available locales for the string, so that there is a chance at
+		 * least one of these will be used as default
+		 */
+		for( i = 0 ; i < g_strv_length( locales ) ; ++i ){
+			g_key_file_set_locale_string( ndf->private->key_file, group, key, locales[i], value );
+		}
+	}
+}
+
+/**
+ * nadp_desktop_file_set_string:
+ * @ndf: this #NadpDesktopFile object.
+ * @group: the name of the group.
+ * @key: the name of the key.
+ * @value: the value to be written.
+ *
+ * Write the given string value.
+ */
+void
+nadp_desktop_file_set_string( const NadpDesktopFile *ndf, const gchar *group, const gchar *key, const gchar *value )
+{
+	g_return_if_fail( NADP_IS_DESKTOP_FILE( ndf ));
+
+	if( !ndf->private->dispose_has_run ){
+
+		g_key_file_set_string( ndf->private->key_file, group, key, value );
+	}
+}
+
+/**
+ * nadp_desktop_file_set_string_list:
+ * @ndf: this #NadpDesktopFile object.
+ * @group: the name of the group.
+ * @key: the name of the key.
+ * @value: the value to be written.
+ *
+ * Write the given list value.
+ */
+void
+nadp_desktop_file_set_string_list( const NadpDesktopFile *ndf, const gchar *group, const gchar *key, GSList *value )
+{
+	gchar **array;
+
+	g_return_if_fail( NADP_IS_DESKTOP_FILE( ndf ));
+
+	if( !ndf->private->dispose_has_run ){
+
+		array = na_core_utils_slist_to_array( value );
+		g_key_file_set_string_list( ndf->private->key_file, group, key, ( const gchar * const * ) array, g_slist_length( value ));
+		g_strfreev( array );
+	}
+}
+
+/**
+ * nadp_desktop_file_set_uint:
+ * @ndf: this #NadpDesktopFile object.
+ * @group: the name of the group.
+ * @key: the name of the key.
+ * @value: the value to be written.
+ *
+ * Write the given uint value.
+ */
+void
+nadp_desktop_file_set_uint( const NadpDesktopFile *ndf, const gchar *group, const gchar *key, guint value )
+{
+	g_return_if_fail( NADP_IS_DESKTOP_FILE( ndf ));
+
+	if( !ndf->private->dispose_has_run ){
+
+		g_key_file_set_integer( ndf->private->key_file, group, key, value );
+	}
+}
+
 /**
  * nadp_desktop_file_write:
  * @ndf: the #NadpDesktopFile instance.
@@ -669,7 +1045,7 @@ nadp_desktop_file_write( NadpDesktopFile *ndf )
 	if( !ndf->private->dispose_has_run ){
 
 		data = g_key_file_to_data( ndf->private->key_file, NULL, NULL );
-		file = g_file_new_for_path( ndf->private->path );
+		file = g_file_new_for_uri( ndf->private->uri );
 
 		stream = g_file_replace( file, NULL, FALSE, G_FILE_CREATE_NONE, NULL, &error );
 		if( error ){
