@@ -4,7 +4,7 @@
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -39,6 +39,7 @@
 
 #include "base-application.h"
 #include "base-iprefs.h"
+#include "nact-iprefs.h"
 #include "base-window.h"
 
 /* private class data
@@ -99,7 +100,8 @@ static gboolean      st_debug_signal_connect = FALSE;
 
 static GType            register_type( void );
 static void             class_init( BaseWindowClass *klass );
-static void             iprefs_iface_init( BaseIPrefsInterface *iface );
+static void             iprefs_base_iface_init( BaseIPrefsInterface *iface );
+static void             iprefs_nact_iface_init( NactIPrefsInterface *iface );
 static void             instance_init( GTypeInstance *instance, gpointer klass );
 static void             instance_get_property( GObject *object, guint property_id, GValue *value, GParamSpec *spec );
 static void             instance_set_property( GObject *object, guint property_id, const GValue *value, GParamSpec *spec );
@@ -112,9 +114,9 @@ static void             v_initial_load_toplevel( BaseWindow *window, gpointer us
 static void             v_runtime_init_toplevel( BaseWindow *window, gpointer user_data );
 static void             v_all_widgets_showed( BaseWindow *window, gpointer user_data );
 static gboolean         v_dialog_response( GtkDialog *dialog, gint code, BaseWindow *window );
-static gchar           *v_get_toplevel_name( BaseWindow *window );
-static gchar           *v_get_iprefs_window_id( BaseWindow *window );
-static gchar           *v_get_ui_filename( BaseWindow *window );
+static gchar           *v_get_toplevel_name( const BaseWindow *window );
+static gchar           *v_get_iprefs_window_id( const BaseWindow *window );
+static gchar           *v_get_ui_filename( const BaseWindow *window );
 
 static void             on_runtime_init_toplevel( BaseWindow *window, gpointer user_data );
 
@@ -123,10 +125,11 @@ static void             window_do_runtime_init_toplevel( BaseWindow *window, gpo
 static void             window_do_all_widgets_showed( BaseWindow *window, gpointer user_data );
 static gboolean         window_do_dialog_response( GtkDialog *dialog, gint code, BaseWindow *window );
 static gboolean         window_do_delete_event( BaseWindow *window, GtkWindow *toplevel, GdkEvent *event );
+static gboolean         window_do_is_willing_to_quit( const BaseWindow *window );
 
 static gboolean         is_main_window( BaseWindow *window );
 static gboolean         is_toplevel_initialized( BaseWindow *window, GtkWindow *toplevel );
-static GtkWindow       *load_named_toplevel( BaseWindow *window, const gchar *name );
+static GtkWindow       *load_named_toplevel( const BaseWindow *window, const gchar *name );
 static GtkWidget       *search_for_widget( GtkWindow *toplevel, const gchar *name );
 static GtkWidget       *search_for_child_widget( GtkContainer *container, const gchar *name );
 static void             set_toplevel_initialized( BaseWindow *window, GtkWindow *toplevel, gboolean init );
@@ -164,8 +167,14 @@ register_type( void )
 		( GInstanceInitFunc ) instance_init
 	};
 
-	static const GInterfaceInfo prefs_iface_info = {
-		( GInterfaceInitFunc ) iprefs_iface_init,
+	static const GInterfaceInfo iprefs_base_iface_info = {
+		( GInterfaceInitFunc ) iprefs_base_iface_init,
+		NULL,
+		NULL
+	};
+
+	static const GInterfaceInfo iprefs_nact_iface_info = {
+		( GInterfaceInitFunc ) iprefs_nact_iface_init,
 		NULL,
 		NULL
 	};
@@ -174,7 +183,9 @@ register_type( void )
 
 	type = g_type_register_static( G_TYPE_OBJECT, "BaseWindow", &info, 0 );
 
-	g_type_add_interface_static( type, BASE_IPREFS_TYPE, &prefs_iface_info );
+	g_type_add_interface_static( type, BASE_IPREFS_TYPE, &iprefs_base_iface_info );
+
+	g_type_add_interface_static( type, NACT_IPREFS_TYPE, &iprefs_nact_iface_info );
 
 	return( type );
 }
@@ -262,6 +273,7 @@ class_init( BaseWindowClass *klass )
 	klass->get_toplevel_name = NULL;
 	klass->get_iprefs_window_id = NULL;
 	klass->get_ui_filename = NULL;
+	klass->is_willing_to_quit = window_do_is_willing_to_quit;
 
 	/**
 	 * nact-signal-base-window-initial-load:
@@ -327,22 +339,31 @@ class_init( BaseWindowClass *klass )
 }
 
 static void
-iprefs_iface_init( BaseIPrefsInterface *iface )
+iprefs_base_iface_init( BaseIPrefsInterface *iface )
 {
-	static const gchar *thisfn = "base_window_iprefs_iface_init";
+	static const gchar *thisfn = "base_window_iprefs_base_iface_init";
 
 	g_debug( "%s: iface=%p", thisfn, ( void * ) iface );
 
 	iface->iprefs_get_window_id = v_get_iprefs_window_id;
 }
 
+static void
+iprefs_nact_iface_init( NactIPrefsInterface *iface )
+{
+	static const gchar *thisfn = "base_window_iprefs_nact_iface_init";
+
+	g_debug( "%s: iface=%p", thisfn, ( void * ) iface );
+}
+
 static void
 instance_init( GTypeInstance *instance, gpointer klass )
 {
 	static const gchar *thisfn = "base_window_instance_init";
 	BaseWindow *self;
 
-	g_debug( "%s: instance=%p, klass=%p", thisfn, ( void * ) instance, ( void * ) klass );
+	g_debug( "%s: instance=%p (%s), klass=%p",
+			thisfn, ( void * ) instance, G_OBJECT_TYPE_NAME( instance ), ( void * ) klass );
 	g_return_if_fail( BASE_IS_WINDOW( instance ));
 	self = BASE_WINDOW( instance );
 
@@ -468,7 +489,7 @@ instance_dispose( GObject *window )
 	BaseWindow *self;
 	GSList *is;
 
-	g_debug( "%s: window=%p", thisfn, ( void * ) window );
+	g_debug( "%s: window=%p (%s)", thisfn, ( void * ) window, G_OBJECT_TYPE_NAME( window ));
 	g_return_if_fail( BASE_IS_WINDOW( window ));
 	self = BASE_WINDOW( window );
 
@@ -511,6 +532,8 @@ instance_dispose( GObject *window )
 			}
 		}
 
+		/* must dispose _after_ quitting the loop
+		 */
 		self->private->dispose_has_run = TRUE;
 
 		/* release the Gtkbuilder, if any
@@ -699,7 +722,7 @@ base_window_run( BaseWindow *window )
  * caller.
  */
 BaseApplication *
-base_window_get_application( BaseWindow *window )
+base_window_get_application( const BaseWindow *window )
 {
 	BaseApplication *application = NULL;
 
@@ -726,7 +749,7 @@ base_window_get_application( BaseWindow *window )
  * #GtkWindow.
  */
 GtkWindow *
-base_window_get_named_toplevel( BaseWindow *window, const gchar *name )
+base_window_get_named_toplevel( const BaseWindow *window, const gchar *name )
 {
 	GtkWindow *toplevel = NULL;
 
@@ -739,6 +762,29 @@ base_window_get_named_toplevel( BaseWindow *window, const gchar *name )
 	return( toplevel );
 }
 
+/**
+ * base_window_get_parent:
+ * @window: this #BaseWindow instance..
+ *
+ * Returns the #BaseWindow parent of @window.
+ *
+ * The returned object is owned by @window, and should not be freed.
+ */
+BaseWindow *
+base_window_get_parent( const BaseWindow *window )
+{
+	BaseWindow *parent = NULL;
+
+	g_return_val_if_fail( BASE_IS_WINDOW( window ), NULL );
+
+	if( !window->private->dispose_has_run ){
+
+		parent = window->private->parent;
+	}
+
+	return( parent );
+}
+
 /**
  * base_window_get_toplevel:
  * @window: this #BaseWindow instance..
@@ -749,7 +795,7 @@ base_window_get_named_toplevel( BaseWindow *window, const gchar *name )
  * #GtkWindow.
  */
 GtkWindow *
-base_window_get_toplevel( BaseWindow *window )
+base_window_get_toplevel( const BaseWindow *window )
 {
 	GtkWindow *toplevel = NULL;
 
@@ -775,7 +821,7 @@ base_window_get_toplevel( BaseWindow *window )
  * g_free() nor g_object_unref() by the caller.
  */
 GtkWidget *
-base_window_get_widget( BaseWindow *window, const gchar *name )
+base_window_get_widget( const BaseWindow *window, const gchar *name )
 {
 	GtkWindow *toplevel;
 	GtkWidget *widget = NULL;
@@ -785,11 +831,41 @@ base_window_get_widget( BaseWindow *window, const gchar *name )
 	if( !window->private->dispose_has_run ){
 		toplevel = window->private->toplevel_window;
 		widget = search_for_widget( toplevel, name );
+		if( !widget ){
+			g_warning( "%s: widget not found", name );
+		}
 	}
 
 	return( widget );
 }
 
+/**
+ * base_window_is_willing_to_quit:
+ * @window: this #BaseWindow instance.
+ *
+ * Returns: %TRUE if the application is willing to quit, %FALSE else.
+ *
+ * This function is called when the session manager detects the end of
+ * session and thus asks its client if they are willing to quit.
+ */
+gboolean
+base_window_is_willing_to_quit( const BaseWindow *window )
+{
+	gboolean willing_to = TRUE;
+
+	g_return_val_if_fail( BASE_IS_WINDOW( window ), willing_to );
+
+	if( !window->private->dispose_has_run ){
+
+		if( BASE_WINDOW_GET_CLASS( window )->is_willing_to_quit ){
+
+			willing_to = BASE_WINDOW_GET_CLASS( window )->is_willing_to_quit( window );
+		}
+	}
+
+	return( willing_to );
+}
+
 /*
  * handler of "delete-event" message
  * let a chance to derived class to handle it
@@ -906,7 +982,7 @@ v_dialog_response( GtkDialog *dialog, gint code, BaseWindow *window )
 }
 
 static gchar *
-v_get_toplevel_name( BaseWindow *window )
+v_get_toplevel_name( const BaseWindow *window )
 {
 	gchar *name = NULL;
 
@@ -927,7 +1003,7 @@ v_get_toplevel_name( BaseWindow *window )
 }
 
 static gchar *
-v_get_iprefs_window_id( BaseWindow *window )
+v_get_iprefs_window_id( const BaseWindow *window )
 {
 	gchar *id = NULL;
 
@@ -944,7 +1020,7 @@ v_get_iprefs_window_id( BaseWindow *window )
 }
 
 static gchar *
-v_get_ui_filename( BaseWindow *window )
+v_get_ui_filename( const BaseWindow *window )
 {
 	gchar *filename = NULL;
 	BaseApplication *application;
@@ -1063,6 +1139,16 @@ window_do_delete_event( BaseWindow *window, GtkWindow *toplevel, GdkEvent *event
 	return( FALSE );
 }
 
+static gboolean
+window_do_is_willing_to_quit( const BaseWindow *window )
+{
+	static const gchar *thisfn = "base_window_do_is_willing_to_quit";
+
+	g_debug( "%s: window=%p", thisfn, ( void * ) window );
+
+	return( TRUE );
+}
+
 static gboolean
 is_main_window( BaseWindow *window )
 {
@@ -1092,7 +1178,7 @@ is_toplevel_initialized( BaseWindow *window, GtkWindow *toplevel )
 }
 
 static GtkWindow *
-load_named_toplevel( BaseWindow *window, const gchar *name )
+load_named_toplevel( const BaseWindow *window, const gchar *name )
 {
 	GtkWindow *toplevel = NULL;
 	BaseApplication *application;
@@ -1138,13 +1224,15 @@ search_for_child_widget( GtkContainer *container, const gchar *name )
 	GList *ic;
 	GtkWidget *found = NULL;
 	GtkWidget *child;
+	const gchar *child_name;
 
 	for( ic = children ; ic ; ic = ic->next ){
 		if( GTK_IS_WIDGET( ic->data )){
 			child = GTK_WIDGET( ic->data );
-			if( child->name && strlen( child->name )){
-				/*g_debug( "%s: child=%s", thisfn, child->name );*/
-				if( !g_ascii_strcasecmp( name, child->name )){
+			child_name = gtk_buildable_get_name( GTK_BUILDABLE( child ));
+			if( child_name && strlen( child_name )){
+				/*g_debug( "%s: child=%s", thisfn, child_name );*/
+				if( !g_ascii_strcasecmp( name, child_name )){
 					found = child;
 					break;
 
@@ -1181,6 +1269,7 @@ setup_builder( BaseWindow *window )
 	BaseApplication *application;
 	gchar *fname;
 	GError *error = NULL;
+	gchar *msg;
 
 	if( window->private->has_own_builder ){
 		window->private->builder = base_builder_new();
@@ -1191,27 +1280,32 @@ setup_builder( BaseWindow *window )
 	}
 
 	fname = v_get_ui_filename( window );
+
 	if( fname && strlen( fname )){
 		if( !base_builder_add_from_file( window->private->builder, fname, &error )){
-			g_warning( "%s: unable to load %s UI XML definition: %s", thisfn, fname, error->message );
+			msg = g_strdup_printf( _( "Unable to load %s UI XML definition: %s" ), fname, error->message );
+			base_window_error_dlg( window, GTK_MESSAGE_WARNING, thisfn, msg );
+			g_free( msg );
 			g_error_free( error );
 		}
+
 		g_free( fname );
 	}
 }
 
 void
-base_window_error_dlg( BaseWindow *window, GtkMessageType type, const gchar *primary, const gchar *secondary )
+base_window_error_dlg( const BaseWindow *window, GtkMessageType type, const gchar *primary, const gchar *secondary )
 {
 	g_return_if_fail( BASE_IS_WINDOW( window ));
 
 	if( !window->private->dispose_has_run ){
+
 		base_application_error_dlg( window->private->application, type, primary, secondary );
 	}
 }
 
 gboolean
-base_window_yesno_dlg( BaseWindow *window, GtkMessageType type, const gchar *first, const gchar *second )
+base_window_yesno_dlg( const BaseWindow *window, GtkMessageType type, const gchar *first, const gchar *second )
 {
 	gboolean yesno = FALSE;
 
@@ -1278,6 +1372,22 @@ base_window_signal_connect_by_name( BaseWindow *window, const gchar *name, const
 	return( handler_id );
 }
 
+gulong
+base_window_signal_connect_with_data( BaseWindow *window, GObject *instance, const gchar *signal, GCallback fn, void *user_data )
+{
+	gulong handler_id = 0;
+
+	g_return_val_if_fail( BASE_IS_WINDOW( window ), ( gulong ) 0 );
+
+	if( !window->private->dispose_has_run ){
+
+		handler_id = g_signal_connect( instance, signal, fn, user_data );
+		record_connected_signal( window, instance, handler_id );
+	}
+
+	return( handler_id );
+}
+
 static void
 record_connected_signal( BaseWindow *window, GObject *instance, gulong handler_id )
 {
