@@ -445,16 +445,18 @@ nact_tree_model_dispose( NactTreeModel *model )
 void
 nact_tree_model_display( NactTreeModel *model, NAObject *object )
 {
-	/*static const gchar *thisfn = "nact_tree_model_display";*/
+	static const gchar *thisfn = "nact_tree_model_display";
 	GtkTreeStore *store;
 	GtkTreeIter iter;
 	GtkTreePath *path;
 
-	/*g_debug( "%s: model=%p (%s), object=%p (%s)", thisfn,
-			( void * ) model, G_OBJECT_TYPE_NAME( model ),
-			( void * ) object, G_OBJECT_TYPE_NAME( object ));*/
 	g_return_if_fail( NACT_IS_TREE_MODEL( model ));
 
+	g_debug( "%s: model=%p (%s), object=%p (%s)",
+			thisfn,
+			( void * ) model, G_OBJECT_TYPE_NAME( model ),
+			( void * ) object, G_OBJECT_TYPE_NAME( object ));
+
 	if( !model->private->dispose_has_run ){
 
 		store = GTK_TREE_STORE( gtk_tree_model_filter_get_model( GTK_TREE_MODEL_FILTER( model )));
@@ -892,6 +894,7 @@ dump_store( NactTreeModel *model, GtkTreePath *path, NAObject *object, ntmDumpSt
 	gint i;
 	GString *prefix;
 	gchar *id, *label;
+	NAObjectItem *origin;
 
 	depth = gtk_tree_path_get_depth( path );
 	prefix = g_string_new( ntm->prefix );
@@ -901,9 +904,11 @@ dump_store( NactTreeModel *model, GtkTreePath *path, NAObject *object, ntmDumpSt
 
 	id = na_object_get_id( object );
 	label = na_object_get_label( object );
-	g_debug( "%s: %s%s at %p (ref_count=%d) \"[%s] %s\"",
+	origin = ( NAObjectItem * ) na_object_get_origin( object );
+	g_debug( "%s: %s%s at %p (ref_count=%d) \"[%s] %s\" origin=%p (%s)",
 			ntm->fname, prefix->str,
-			G_OBJECT_TYPE_NAME( object ), ( void * ) object, G_OBJECT( object )->ref_count, id, label );
+			G_OBJECT_TYPE_NAME( object ), ( void * ) object, G_OBJECT( object )->ref_count, id, label,
+			( void * ) origin, origin ? G_OBJECT_TYPE_NAME( object ) : "null" );
 	g_free( label );
 	g_free( id );
 
@@ -1013,8 +1018,8 @@ iter_on_store_item( NactTreeModel *model, GtkTreeModel *store, GtkTreeIter *iter
 	 * unchanged in dump_store
 	 */
 	g_object_unref( object );
-	/*g_debug( "nact_tree_model_iter_on_store_item: object=%p (%s, ref_count=%d)",
-			( void * ) object, G_OBJECT_TYPE_NAME( object ), G_OBJECT( object )->ref_count );*/
+	g_debug( "nact_tree_model_iter_on_store_item: object=%p (%s, ref_count=%d)",
+			( void * ) object, G_OBJECT_TYPE_NAME( object ), G_OBJECT( object )->ref_count );
 
 	path = gtk_tree_model_get_path( store, iter );
 
