@@ -193,6 +193,8 @@ instance_init( GTypeInstance *instance, gpointer klass )
 	self->private = g_new0( NautilusActionsPrivate, 1 );
 
 	self->private->dispose_has_run = FALSE;
+
+	na_ipivot_consumer_allow_notify( NA_IPIVOT_CONSUMER( instance ), TRUE, 0 );
 }
 
 static void
@@ -754,8 +756,9 @@ build_nautilus_menus( NautilusActions *plugin, GList *tree, guint target, GList
 		 */
 		if( NA_IS_OBJECT_MENU( it->data )){
 			subitems = na_object_get_items( it->data );
+			g_debug( "%s: menu has %d items", thisfn, g_list_length( subitems ));
 			submenu = build_nautilus_menus( plugin, subitems, target, files, tokens );
-			/*g_debug( "%s: submenu has %d items", thisfn, g_list_length( submenu ));*/
+			g_debug( "%s: submenu has %d items", thisfn, g_list_length( submenu ));
 
 			if( submenu ){
 				if( target == ITEM_TARGET_TOOLBAR ){
